@@ -14,30 +14,25 @@
 #' @source NYC Open Data: <https://data.cityofnewyork.us/Health/New-York-City-Leading-Causes-of-Death/jb7j-dtam/about_data>
 #'
 #' @examples
-#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # Examples that hit the live NYC Open Data API are guarded so CRAN checks
 #' # do not fail when the network is unavailable or slow.
-#' \donttest{
-#' if (curl::has_internet()) {
+#' if (interactive() && curl::has_internet()) {
 #'   # Quick example (fetch 2 rows)
 #'   small_sample <- nyc_cause_of_death(limit = 2)
 #'   small_sample
 #'
-#'   nyc_cause_of_death(filters = list(sex = "M"))
-#' }
+#'   nyc_cause_of_death(limit = 2, filters = list(sex = "M"))
 #' }
 #' @export
 nyc_cause_of_death <- function(limit = 10000, filters = list(), timeout_sec = 30) {
-  endpoint <- "https://data.cityofnewyork.us/resource/jb7j-dtam.json"
+  endpoint <- .nyc_endpoint("jb7j-dtam")
 
   query_list <- list(
     "$limit" = limit,
     "$order" = "year DESC"
   )
 
-  if (length(filters) > 0) {
-    where_clauses <- paste0(names(filters), " = '", unlist(filters), "'")
-    query_list[["$where"]] <- paste(where_clauses, collapse = " AND ")
-  }
+  query_list <- .nyc_add_filters(query_list, filters)
 
   data <- .nyc_get_json(endpoint, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
