@@ -15,30 +15,25 @@
 #' @source NYC Open Data: <https://data.cityofnewyork.us/resource/vx8i-nprf>
 #'
 #' @examples
-#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # Examples that hit the live NYC Open Data API are guarded so CRAN checks
 #' # do not fail when the network is unavailable or slow.
-#' \donttest{
-#' if (curl::has_internet()) {
+#' if (interactive() && curl::has_internet()) {
 #'   # Quick example (fetch 2 rows)
 #'   small_sample <- nyc_civil_service_list(limit = 2)
 #'   small_sample
 #'
-#'   nyc_civil_service_list(filters = list(last_name = "Martinez"))
-#' }
+#'   nyc_civil_service_list(limit = 2, filters = list(last_name = "Martinez"))
 #' }
 #' @export
 nyc_civil_service_list <- function(limit = 10000, filters = list(), timeout_sec = 30) {
-  endpoint <- "https://data.cityofnewyork.us/resource/vx8i-nprf.json"
+  endpoint <- .nyc_endpoint("vx8i-nprf")
 
   query_list <- list(
     "$limit" = limit,
     "$order" = "published_date DESC"
   )
 
-  if (length(filters) > 0) {
-    where_clauses <- paste0(names(filters), " = '", unlist(filters), "'")
-    query_list[["$where"]] <- paste(where_clauses, collapse = " AND ")
-  }
+  query_list <- .nyc_add_filters(query_list, filters)
 
   data <- .nyc_get_json(endpoint, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
