@@ -13,30 +13,28 @@
 #' @source NYC Open Data: <https://data.cityofnewyork.us/Education/2018-2019-Daily-Attendance/x3bb-kg5j/about_data>
 #'
 #' @examples
-#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # Examples that hit the live NYC Open Data API are guarded so CRAN checks
 #' # do not fail when the network is unavailable or slow.
-#' \donttest{
-#' if (curl::has_internet()) {
+#' if (interactive() && curl::has_internet()) {
 #'   # Quick example (fetch 2 rows)
 #'   small_sample <- nyc_daily_attendance_2018_2019(limit = 2)
 #'   small_sample
 #'
-#'   nyc_daily_attendance_2018_2019(filters = list(school_dbn = "01M015"))
-#' }
+#'   nyc_daily_attendance_2018_2019(
+#'     limit = 2,
+#'     filters = list(school_dbn = "01M015")
+#'   )
 #' }
 #' @export
 nyc_daily_attendance_2018_2019 <- function(limit = 10000, filters = list(), timeout_sec = 30) {
-  endpoint <- "https://data.cityofnewyork.us/resource/x3bb-kg5j.json"
+  endpoint <- .nyc_endpoint("x3bb-kg5j")
 
   query_list <- list(
     "$limit" = limit,
     "$order" = "date DESC"
   )
 
-  if (length(filters) > 0) {
-    where_clauses <- paste0(names(filters), " = '", unlist(filters), "'")
-    query_list[["$where"]] <- paste(where_clauses, collapse = " AND ")
-  }
+  query_list <- .nyc_add_filters(query_list, filters)
 
   data <- .nyc_get_json(endpoint, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
