@@ -15,30 +15,26 @@
 #' @source NYC Open Data: <https://data.cityofnewyork.us/City-Government/Film-Permits/tg4x-b46p/about_data>
 #'
 #' @examples
-#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # Examples that hit the live NYC Open Data API are guarded so CRAN checks
 #' # do not fail when the network is unavailable or slow.
-#' \donttest{
-#' if (curl::has_internet()) {
+#' if (interactive() && curl::has_internet()) {
 #'   # Quick example (fetch 2 rows)
 #'   small_sample <- nyc_film_permits(limit = 2)
 #'   small_sample
 #'
-#'   nyc_film_permits(filters = list(eventtype = "Shooting Permit"))
-#' }
+#'   nyc_film_permits(limit = 2, filters = list(eventtype = "Shooting Permit"))
 #' }
+#'
 #' @export
 nyc_film_permits <- function(limit = 10000, filters = list(), timeout_sec = 30) {
-  endpoint <- "https://data.cityofnewyork.us/resource/tg4x-b46p.json"
+  endpoint <- .nyc_endpoint("tg4x-b46p")
 
   query_list <- list(
     "$limit" = limit,
     "$order" = "enteredon DESC"
   )
 
-  if (length(filters) > 0) {
-    where_clauses <- paste0(names(filters), " = '", unlist(filters), "'")
-    query_list[["$where"]] <- paste(where_clauses, collapse = " AND ")
-  }
+  query_list <- .nyc_add_filters(query_list, filters)
 
   data <- .nyc_get_json(endpoint, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
