@@ -13,29 +13,24 @@
 #' @source NYC Open Data: <https://data.cityofnewyork.us/Social-Services/Directory-Of-Homeless-Drop-In-Centers/bmxf-3rd4/about_data>
 #'
 #' @examples
-#' # Examples that hit the live NYC Open Data API are wrapped so CRAN checks
+#' # Examples that hit the live NYC Open Data API are guarded so CRAN checks
 #' # do not fail when the network is unavailable or slow.
-#' \donttest{
-#' if (curl::has_internet()) {
+#' if (interactive() && curl::has_internet()) {
 #'   # Quick example (fetch 2 rows)
 #'   small_sample <- nyc_homeless_drop_in_centers(limit = 2)
 #'   small_sample
 #'
-#'   nyc_homeless_drop_in_centers(filters = list(borough = "Bronx"))
-#' }
+#'   nyc_homeless_drop_in_centers(limit = 2, filters = list(borough = "Bronx"))
 #' }
 #' @export
 nyc_homeless_drop_in_centers <- function(limit = 10000, filters = list(), timeout_sec = 30) {
-  endpoint <- "https://data.cityofnewyork.us/resource/bmxf-3rd4.json"
+  endpoint <- .nyc_endpoint("bmxf-3rd4")
 
   query_list <- list(
     "$limit" = limit
   )
 
-  if (length(filters) > 0) {
-    where_clauses <- paste0(names(filters), " = '", unlist(filters), "'")
-    query_list[["$where"]] <- paste(where_clauses, collapse = " AND ")
-  }
+  query_list <- .nyc_add_filters(query_list, filters)
 
   data <- .nyc_get_json(endpoint, query_list, timeout_sec = timeout_sec)
   tibble::as_tibble(data)
