@@ -10,3 +10,9 @@ test_that("nyc_311_2010_2019 returns a tibble and respects limits", {
     expect_equal(nrow(results), 2)
   })
 })
+
+test_that("nyc_311_2010_2019 throws errors for bad inputs", {
+  # This touches the new 'stop' lines you just added
+  expect_error(nyc_311_2010_2019(limit = "a string"))
+  expect_error(nyc_311_2010_2019(filters = "not a list"))
+})
